==> ovito_3.10.5~ds.orig.tar.xz: ovito-v3.10.5/src/ovito/particles/gui/modifier/properties/ParticlesComputePropertyModifierDelegateEditor.h <==
////////////////////////////////////////////////////////////////////////////////////////
//
//  Copyright 2023 OVITO GmbH, Germany
//
//  This file is part of OVITO (Open Visualization Tool).
//
//  OVITO is free software; you can redistribute it and/or modify it either under the
//  terms of the GNU General Public License version 3 as published by the Free Software
//  Foundation (the "GPL") or, at your option, under the terms of the MIT License.
//  If you do not alter this notice, a recipient may use your version of this
//  file under either the GPL or the MIT License.
//
//  You should have received a copy of the GPL along with this program in a
//  file LICENSE.GPL.txt.  You should have received a copy of the MIT License along
//  with this program in a file LICENSE.MIT.txt
//
//  This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
//  either express or implied. See the GPL or the MIT License for the specific language
//  governing rights and limitations.
//
////////////////////////////////////////////////////////////////////////////////////////

#pragma once


#include <ovito/particles/gui/ParticlesGui.h>
#include <ovito/gui/desktop/properties/PropertiesEditor.h>
#include <ovito/gui/desktop/utilities/DeferredMethodInvocation.h>

namespace Ovito {

/**
 * A properties editor for the ParticlesComputePropertyModifierDelegate class.
 */
class ParticlesComputePropertyModifierDelegateEditor : public PropertiesEditor
{
    OVITO_CLASS(ParticlesComputePropertyModifierDelegateEditor)

public:

    /// Default constructor.
    Q_INVOKABLE ParticlesComputePropertyModifierDelegateEditor() {}

protected:

    /// Creates the user interface controls for the editor.
    virtual void createUI(const RolloutInsertionParameters& rolloutParams) override;

    /// This method is called when a reference target changes.
    virtual bool referenceEvent(RefTarget* source, const ReferenceEvent& event) override;

protected Q_SLOTS:

    /// Is called when the user has typed in an expression.
    void onExpressionEditingFinished();

    /// Updates the editor's input fields for the expressions.
    void updateExpressionFields();

    /// Updates the editor's display of the available expression variables.
    void updateVariablesList();

private:

    QGroupBox* neighborExpressionsGroupBox;
    QList<AutocompleteLineEdit*> neighborExpressionLineEdits;
    QList<AutocompleteTextEdit*> neighborExpressionTextEdits;
    QList<QLabel*> neighborExpressionLabels;
    QGridLayout* neighborExpressionsLayout;

    // For deferred invocation of the UI update functions.
    DeferredMethodInvocation<ParticlesComputePropertyModifierDelegateEditor, &ParticlesComputePropertyModifierDelegateEditor::updateExpressionFields> updateExpressionFieldsLater;
    DeferredMethodInvocation<ParticlesComputePropertyModifierDelegateEditor, &ParticlesComputePropertyModifierDelegateEditor::updateVariablesList> updateVariablesListLater;
};

}   // End of namespace

==> ovito_3.13.1~ds.orig.tar.xz: ovito-v3.13.1/src/ovito/particles/gui/modifier/properties/ParticlesComputePropertyModifierDelegateEditor.h <==
////////////////////////////////////////////////////////////////////////////////////////
//
//  Copyright 2025 OVITO GmbH, Germany
//
//  This file is part of OVITO (Open Visualization Tool).
//
//  OVITO is free software; you can redistribute it and/or modify it either under the
//  terms of the GNU General Public License version 3 as published by the Free Software
//  Foundation (the "GPL") or, at your option, under the terms of the MIT License.
//  If you do not alter this notice, a recipient may use your version of this
//  file under either the GPL or the MIT License.
//
//  You should have received a copy of the GPL along with this program in a
//  file LICENSE.GPL.txt.  You should have received a copy of the MIT License along
//  with this program in a file LICENSE.MIT.txt
//
//  This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
//  either express or implied. See the GPL or the MIT License for the specific language
//  governing rights and limitations.
//
////////////////////////////////////////////////////////////////////////////////////////

#pragma once


#include <ovito/particles/gui/ParticlesGui.h>
#include <ovito/gui/desktop/properties/PropertiesEditor.h>
#include <ovito/gui/desktop/utilities/DeferredMethodInvocation.h>

namespace Ovito {

/**
 * A properties editor for the ParticlesComputePropertyModifierDelegate class.
 */
class ParticlesComputePropertyModifierDelegateEditor : public PropertiesEditor
{
    OVITO_CLASS(ParticlesComputePropertyModifierDelegateEditor)
    Q_OBJECT

protected:

    /// Creates the user interface controls for the editor.
    virtual void createUI(const RolloutInsertionParameters& rolloutParams) override;

    /// This method is called when a reference target changes.
    virtual bool referenceEvent(RefTarget* source, const ReferenceEvent& event) override;

protected Q_SLOTS:

    /// Is called when the user has typed in an expression.
    void onExpressionEditingFinished();

    /// Updates the editor's input fields for the expressions.
    void updateExpressionFields();

    /// Updates the editor's display of the available expression variables.
    void updateVariablesList();

private:

    QGroupBox* neighborExpressionsGroupBox;
    QList<AutocompleteLineEdit*> neighborExpressionLineEdits;
    QList<AutocompleteTextEdit*> neighborExpressionTextEdits;
    QList<QLabel*> neighborExpressionLabels;
    QGridLayout* neighborExpressionsLayout;
	QLabel* expandFieldsLabel;

    // For deferred invocation of the UI update functions.
    DeferredMethodInvocation<ParticlesComputePropertyModifierDelegateEditor, &ParticlesComputePropertyModifierDelegateEditor::updateExpressionFields> updateExpressionFieldsLater;
    DeferredMethodInvocation<ParticlesComputePropertyModifierDelegateEditor, &ParticlesComputePropertyModifierDelegateEditor::updateVariablesList> updateVariablesListLater;
};

}   // End of namespace
